@@ -41,6 +41,7 @@ class ForceReply(ReplyMarkup):
                original message.
 
         **kwargs (:obj:`dict`): Arbitrary keyword arguments.
+
     """
 
     def __init__(self, force_reply=True, selective=False, **kwargs):
@@ -48,10 +49,3 @@ class ForceReply(ReplyMarkup):
         self.force_reply = bool(force_reply)
         # Optionals
         self.selective = bool(selective)
-
-    @classmethod
-    def de_json(cls, data, bot):
-        if not data:
-            return None
-
-        return cls(**data)
